Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnableConfigHierarchy ¶
func EnableConfigHierarchy()
EnableConfigHierarchy is to allow config options such as config.<x.y> with
dots as the config key
func ProcessAutostart ¶
ProcessAutostart will start and enable the listed app(s) based on the value of autostart snap option
func ProcessConfig ¶
ProcessConfig processes snap configuration which can be used to override app configuration via environment variables sourced by the snap service wrapper script. A service specific file (named <service>.env) is created in the $SNAP_DATA/config/res directory. The settings can either be app-specific or apply to all services/apps in the snap a) snap set edgex-snap-name apps.<app>.config.<my.env.var>
-> sets env var MY_ENV_VAR for an app
b) snap set edgex-snap-name config.<my.env.var>
-> sets env variable for all apps (e.g. DEBUG=true, SERVICE_SERVERBINDADDRESS=0.0.0.0)
func SetHierarchySeparator ¶
func SetHierarchySeparator(sep string)
SetHierarchySeparator sets the separator used to replace dots in config.<x.y> Default is _
func SetSegmentSeparator ¶
func SetSegmentSeparator(sep string)
SetSegmentSeparator sets the separator used to replace hyphens in config.<x-y> Default is _
Types ¶
This section is empty.